---
slug: /introduction
sidebar_position: 1
---

# What is Therix.ai?

Therix simplifies the adoption of GenAI for enterprises, enabling them to build, deploy, and monitor scalable GenAI applications and agents. Ensure your operations are secure, private, and compliant with our private SDKs.

# How does it work?

Therix is generally available as a SaaS offering on [app.therix.ai](http://app.therix.ai). You can create your custom AI workflows ( called pipelines within therix ), and use our SDK to integrate with your apps. 

If you are looking for a self-hosted enterprise solution, reach out to us at [enterprise@therix.ai](mailto:enterprise@therix.ai)

# What all can i build with therix?

TBD

